@@ -281,9 +281,13 @@ int win_build_buf_menu(struct win *win) {
  * Return:	-1 for failure, 0 for success.
  */
 int win_set_buf(struct win *win, Sbuf *buf) {
-	if (!sbuf_has_flags(buf, SBUF_LOADED_FLAG))
-		if (sbuf_load(buf) == -1)
+	if (!sbuf_has_flags(buf, SBUF_LOADED_FLAG)) {
+		if (sbuf_load(buf) == -1) {
+			error(win, "Error loading file into memory: %s",
+				sbuf_get_name(buf));
 			return -1;
+		}
+	}
 	if (editwin_set_buf(win->ew, buf) == -1)
 		return -1;
 	win->click_pos = -1;
